@@ -8,11 +8,7 @@
 #define OPENBLAS_PTHREAD_CREATE_FUNC pthread_create
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
-#define OPENBLAS_ARMV7 
-#define OPENBLAS_HAVE_VFP 
-#define OPENBLAS_HAVE_VFPV3 
-#define OPENBLAS_HAVE_NEON 
-#define OPENBLAS_HAVE_VFPV4 
+#define OPENBLAS_ARMV6 
 #define OPENBLAS_L1_DATA_SIZE 65536
 #define OPENBLAS_L1_DATA_LINESIZE 32
 #define OPENBLAS_L2_SIZE 512488
@@ -20,9 +16,11 @@
 #define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_DTB_SIZE 4096
 #define OPENBLAS_L2_ASSOCIATIVE 4
-#define OPENBLAS_CHAR_CORENAME "ARMV7"
+#define OPENBLAS_HAVE_VFP 
+#define OPENBLAS_CORE_ARMV6 
+#define OPENBLAS_CHAR_CORENAME "ARMV6"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.12 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.13 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
